@@ -6,7 +6,7 @@ use warnings;
 use Exporter qw(import);
 use XSLoader;
 
-our $VERSION    = '0.04';
+our $VERSION    = '0.05';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -47,15 +47,16 @@ list of array references.
 
 This distribution contains a benchmarking script which compares several
 modules available on CPAN. These are the results on a MacBook 2.6GHz Core i5
-(64-bit) with Perl 5.26.1:
+(64-bit) with Perl 5.28:
 
-    Set::CrossProduct           31.17+-0.2/s
-    List::MapMulti             34.16+-0.21/s
-    Algorithm::Loops             86.3+-1.5/s
-    Set::Scalar               138.15+-0.56/s
-    Math::Cartesian::Product      244+-1.8/s
-    Set::Product::PP              306+-3.6/s
-    Set::Product::XS         1066.58+-0.24/s
+    Set::CrossProduct        29.7/s
+    List::MapMulti           34.5/s
+    Algorithm::Loops         92.5/s
+    Set::Scalar               126/s
+    Math::Cartesian::Product  237/s
+    Set::Product::PP          301/s
+    Math::Prime::Util         914/s
+    Set::Product::XS          932/s
 
 =head1 SEE ALSO
 
@@ -102,7 +103,7 @@ L<http://search.cpan.org/dist/Set-Product-XS/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015-2017 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2015-2019 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
